Page 94 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 94

Home

    One of the ways the conspirators were able to get the
    United States into World War I was by getting their man,
    Woodrow Wilson, into the White House. Wilson was
    elevated from his position as president of Princeton
    University to governor of New Jersey. After agreeing to
    follow certain principles, should he be elected, Wilson
    was backed for President by the Money Trust. One of
    the principles Wilson agreed upon was to listen to the
    advice of the Money Trust should war break out in

    n 1 a mn

    who wrote to him on Feb. 14, 1917, urging that he go
    ahead with world war for world peace.

    At this time the American people had no interest in
    getting involved in a European war. Wilson even ran for
    his second term on the slogan "he kept us out of war."
    Once back in the White House, he began to push for
    United States entry into World War I. Two outspoken
    opponents of United States involvement in the war were
    Henry Ford and Charles A. Lindbergh Sr.

    To get the United Sates to declare war on Germany,
    Wilson contrived with Winston Churchill for the sinking
    of the Lusitania. This was accomplished by using the
    Lusitania as a munitions ship. Prior to being sunk, it was
    sent into U-boat infested waters carrying six million
    rounds of ammunition, ordered to reduce speed, and
    deserted by its escort. Hit by a single torpedo, it sank in
    eighteen minutes due to internal explosions. This
    information was later revealed by Commander Joseph
    Kenworthy, who was, at the time, a member of British

    This

    89

    Building Modern Babylon

    Europe. He became a close friend of Andrew Carnegie